==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/GrupaZnakowKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;
import pl.topteam.security.password.gen.CharacterGroup;

@GeneratePojoBuilder
public class GrupaZnakowKey extends GenericDPSObject {
    /**
     * GRUPA_ZNAKOW.POLITYKA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long politykaId;

    /**
     * GRUPA_ZNAKOW.GRUPA_ZNAKOW
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private CharacterGroup grupaZnakow;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return GRUPA_ZNAKOW.POLITYKA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPolitykaId() {
        return politykaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * GRUPA_ZNAKOW.POLITYKA_ID
     *
     * @param politykaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPolitykaId(Long politykaId) {
        this.politykaId = politykaId;
    }

    /**
     * @return GRUPA_ZNAKOW.GRUPA_ZNAKOW
     * @mbggenerated 2014-03-10 10:45:37
     */
    public CharacterGroup getGrupaZnakow() {
        return grupaZnakow;
    }

    /**
     * GRUPA_ZNAKOW.GRUPA_ZNAKOW
     *
     * @param grupaZnakow
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setGrupaZnakow(CharacterGroup grupaZnakow) {
        this.grupaZnakow = grupaZnakow;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        GrupaZnakowKey other = (GrupaZnakowKey) that;
        return (this.getPolitykaId() == null ? other.getPolitykaId() == null : this.getPolitykaId().equals(other.getPolitykaId()))
            && (this.getGrupaZnakow() == null ? other.getGrupaZnakow() == null : this.getGrupaZnakow().equals(other.getGrupaZnakow()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getPolitykaId() == null) ? 0 : getPolitykaId().hashCode());
        result = prime * result + ((getGrupaZnakow() == null) ? 0 : getGrupaZnakow().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", politykaId=").append(politykaId);
        sb.append(", grupaZnakow=").append(grupaZnakow);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/GrupaZnakowKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;
import pl.topteam.security.password.gen.CharacterGroup;

@GeneratePojoBuilder
public class GrupaZnakowKey extends GenericDPSObject {
    /**
     * GRUPA_ZNAKOW.POLITYKA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long politykaId;

    /**
     * GRUPA_ZNAKOW.GRUPA_ZNAKOW
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private CharacterGroup grupaZnakow;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return GRUPA_ZNAKOW.POLITYKA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPolitykaId() {
        return politykaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * GRUPA_ZNAKOW.POLITYKA_ID
     *
     * @param politykaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPolitykaId(Long politykaId) {
        this.politykaId = politykaId;
    }

    /**
     * @return GRUPA_ZNAKOW.GRUPA_ZNAKOW
     * @mbggenerated 2014-03-13 16:02:38
     */
    public CharacterGroup getGrupaZnakow() {
        return grupaZnakow;
    }

    /**
     * GRUPA_ZNAKOW.GRUPA_ZNAKOW
     *
     * @param grupaZnakow
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setGrupaZnakow(CharacterGroup grupaZnakow) {
        this.grupaZnakow = grupaZnakow;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        GrupaZnakowKey other = (GrupaZnakowKey) that;
        return (this.getPolitykaId() == null ? other.getPolitykaId() == null : this.getPolitykaId().equals(other.getPolitykaId()))
            && (this.getGrupaZnakow() == null ? other.getGrupaZnakow() == null : this.getGrupaZnakow().equals(other.getGrupaZnakow()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getPolitykaId() == null) ? 0 : getPolitykaId().hashCode());
        result = prime * result + ((getGrupaZnakow() == null) ? 0 : getGrupaZnakow().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", politykaId=").append(politykaId);
        sb.append(", grupaZnakow=").append(grupaZnakow);
        sb.append("]");
        return sb.toString();
    }
}
